package com.ether;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;
import java.security.InvalidParameterException;
import java.util.Locale;
import java.util.ResourceBundle;

public final class WebHelper
{
    private WebHelper()
    {
    }

    public static String getRequestParameter( @NotNull final HttpServletRequest httpServletRequest, @Nullable final String parameterName, @Nullable final String defaultParameterValue, final boolean canBeNull )
            throws InvalidParameterException
    {
        String parameterValue = httpServletRequest.getParameter( parameterName );

        if( parameterValue == null )
            parameterValue = defaultParameterValue;

        if( !canBeNull && parameterValue == null )
            throw new InvalidParameterException( parameterName );

        return parameterValue;
    }

    public static void writeJsonToResponse( @NotNull final HttpServletResponse httpServletResponse, @NotNull final String data )
            throws IOException
    {
        httpServletResponse.setCharacterEncoding( UTF8Charset.getEncoding() );
        httpServletResponse.setContentType( CONTENT_TYPE_TEXT_JSON );

        final PrintWriter writer = httpServletResponse.getWriter();

//        writer.write( JSON_TAG_BEGIN );
        writer.write( data );
//        writer.write( JSON_TAG_END );
    }

    public static void displayAjaxError( @NotNull final HttpServletResponse response, @Nullable final String methodName )
            throws FormattedException
    {
        try
        {
            response.setStatus( HttpServletResponse.SC_NOT_IMPLEMENTED );
            response.setCharacterEncoding( UTF8Charset.getEncoding() );
            response.setContentType( "text/plain;charset=" + UTF8Charset.getEncoding() );
            final ServletOutputStream outputStream = response.getOutputStream();
            outputStream.print( "error.method_not_implemented : " + methodName + " is not implemented." );
            outputStream.flush();
            outputStream.close();
        }
        catch( IOException e )
        {
            throw new FormattedException( FormattedException.FormattedExceptionCode.IO_EXCEPTION_ERROR_TO_GET_OUTPUTSTREAM, e );
        }
    }

    @NotNull
    public static ResourceBundle getBundle( @Nullable final Locale locale )
    {
        if( null != locale )
            return ResourceBundle.getBundle( "ApplicationResources", locale );
        else
            return ResourceBundle.getBundle( "ApplicationResources" );
    }

    private static final Log LOGGER = LogFactory.getLog( WebHelper.class );

    public static final int STATUS_CODE_SERVICE_EXCEPTION = 500;
    public static final String CONTENT_TYPE_TEXT_JSON = "text/javascript;charset=" + UTF8Charset.getEncoding();

    private static final char JSON_TAG_BEGIN = ' ';  // '(';
    private static final char JSON_TAG_END = ' ';     // ')';
}
